@@ -34,4 +34,6 @@ done < ${UPDATE_DIR}/conf/update-jobs.cfg
 echo "Update Done"
 echo "Update Done" > ${UPDATE_WORKING}/update.status
 echo ${rc} > ${UPDATE_WORKING}/update.done
+# add little sleep so done can be detected before pid's gone
+sleep 0.5
 rm -f ${UPDATE_WORKING}/update.pid
