@@ -91,6 +91,7 @@ class Fs_lcr_module_class extends Fs_module_class {
 
         return parent::configure();
     }
+    /*
     public function get_data_settings()
     {
         $data = array(
@@ -115,6 +116,7 @@ class Fs_lcr_module_class extends Fs_module_class {
                 );
         return $data;
     }
+     */
     /**
      * @brief Return existing carrier
      *
@@ -182,6 +184,11 @@ class Fs_lcr_module_class extends Fs_module_class {
      */
     private function _generate_config(&$config_manager)
     {
+        // Ensure the lcr table is autoincrement
+        $db = $this->db($value['data']);
+        $db->connect();
+        $db->query('ALTER TABLE lcr MODIFY COLUMN id INT(11) auto_increment;');
+        $db->disconnect();
         // Cleanup
         //Handle deleted Carrier Profile
         $deleted_carrier = Safe_object_serializer_class::get_serializer()->find_deleted_objects(
@@ -223,24 +230,16 @@ class Fs_lcr_module_class extends Fs_module_class {
         }
         // Write carriers
         foreach($this->carriers() as $profile) {
-            //Handle LCR Rate Profiles
-            $deleted_lcr_rate = Safe_object_serializer_class::get_serializer()->find_deleted_objects(
-                    $profile->path() . '/' .$profile->name() . '/rate');
-            foreach ($deleted_lcr_rate as $lcr_rate_name => $value) {
-                unset($data);
-                $data['data'] = $value['data'];
-                $data['db_class'] = $this->db($value['data']);
-                $data['data']['lcr_profile'] = $lcr_rate_name;
-                $data['primary_key'] = array(
-                        'lcr_profile'
-                );
-                $config_manager->add_config(
-                        new Safe_configuration_class(
-                                'lcr',
-                                $data,
-                                Safe_configuration_class::CFG_DELETE,
-                                Safe_configuration_class::CFG_SQL));
-            }
+            // Delete all rates as they are now stored in the carrier object, so 
+            // we have no clue what is new, up to date nor deleted.
+            $tmp_data['db_class'] = $this->db($profile);
+            $tmp_data['primary_key'] = array(
+                    'carrier_id'
+            );
+            $tmp_data['data']['carrier_id'] = $profile->id();
+            //delete from lcr
+            $config_manager->add_config(new Safe_configuration_class('lcr', 
+                    $tmp_data, Safe_configuration_class::CFG_DELETE, Safe_configuration_class::CFG_SQL));
             if (!$this->_write_carrier($config_manager, $profile)) { 
                 return false;
             }
@@ -255,6 +254,7 @@ class Fs_lcr_module_class extends Fs_module_class {
         $db = $this->db($profile);
         $data['db_class'] = $db;
         $data['data'] = $profile->get_data_values(false);
+        unset($data['data']['rates']);
         $binding_name = $data['data']['binding_name'];
         unset($data['data']['binding_name']);
         $data['data']['carrier_name'] = $profile->name();
@@ -317,42 +317,22 @@ class Fs_lcr_module_class extends Fs_module_class {
         }
         
         //Serialize Carrier Rates
-        $rates = $profile->carrier_rate();
-        if (isset($rates)) {
-            foreach ($rates as $rate) {
-                $status = $rate->status();
-                unset($data['data']);
-                $data['data'] = $rate->get_data_values(false);
-                foreach ($data['data'] as $k => $v) {
-                    if (preg_match('"\bdb-cfg\b"', $k)) {
-                        unset($data['data'][$k]);
-                    }
-                    switch ($k) {
-                    case 'date_start':
-                        if (!strlen(trim($v))) $data['data'][$k] = '1970-01-01 00:00:00';
-                        break;
+        $rates= $profile->get_aggregate_objects('rate');
+        unset($data['data']);
+        $data['db_class'] = $db;
+        $data['data'] = array();
+        foreach($rates as $rate){
 
-                    case 'date_end':
-                        if (!strlen(trim($v))) $data['data'][$k] = '2030-12-31 00:00:00';
-                        break;
-                    }
-                }
-                $data['data']['lcr_profile'] = $rate->name();
-                $data['data']['id'] = $rate->id();
-                $data['data']['carrier_id'] = $profile->id();
-                //Determine whether to update or insert a rule
-                if ($status == Safe_object_serializer_class::OBJ_STATUS_MODIFIED) {
-                    $data['primary_key'] = array(
-                        'id'
-                    );
-                    $config_manager->add_config(new Safe_configuration_class('lcr', 
-                            $data, Safe_configuration_class::CFG_UPDATE, Safe_configuration_class::CFG_SQL));
-                } elseif ($status == Safe_object_serializer_class::OBJ_STATUS_NEW) {
-                    $config_manager->add_config(new Safe_configuration_class('lcr', 
-                            $data, Safe_configuration_class::CFG_CREATE, Safe_configuration_class::CFG_SQL));
-                }
+            if($rate->is_enabled()){
+                // Ask rate to populate load_INFILE 
+                $rate->create_load_infile($data['data'], $profile, $keys);
+
+                // create config task
+                $config_manager->add_config(new Safe_configuration_class('lcr', 
+                        $data, Safe_configuration_class::CFG_LOAD, Safe_configuration_class::CFG_SQL));
             }
         }
+
         return true;
     }
     
@@ -416,7 +396,7 @@ class Fs_lcr_module_class extends Fs_module_class {
         if($carriers[$name]) {
             if($carriers[$name]->can_dispose()) {
                 foreach ($carriers[$name]->has_aggregate_objects(false, true) as $_type => $_definition){
-                    if($_definition['configurable']){
+                    if('rate' !== $_type && $_definition['configurable']){
                         foreach ($carriers[$name]->get_aggregate_objects($_type) as $sub_obj_name => $sub_object) {
                             $sub_object->dispose();
                         }    
@@ -427,80 +407,6 @@ class Fs_lcr_module_class extends Fs_module_class {
         }
         return false;
     }
-    public function api_upload_ratefile($name=null, $data = null, &$output = null){
-        $data_def = $this->get_data_settings();
-        $upload_api_method  = $data_def['ratefile']['methods']['upload']['request'];
-        if($upload_api_method){
-            return $this->upload_data('ratefile', $name , $output , $upload_api_method);
-        }else{
-            $output['message'] = 'Upload request method error.';
-            return false;
-        }
-    }
-    public function initialize_data($data_name = null, $data_key = null, &$output = null, $name = null)
-    {
-        $ini_result = false;
-        $data_cfg = $this->get_data_settings();
-        $data_cfg = $data_cfg[$data_name];
-        $file = $data_cfg['pattern'];
-        $ext = pathinfo($file);
-        $file = $ext['dirname'].'/'.$data_key;
-        $obj = $this->api_retrieve_carrier($name);
-        $old_rate_objects = $obj->get_aggregate_objects('rate');
-        if($obj){
-            ini_set('auto_detect_line_endings',TRUE);
-            $handle = fopen($file,'r');
-            if ($handle) {
-                $csv_data = array();
-                while ( ($csv_data[] = fgetcsv($handle) ) !== FALSE ) {
-                }
-                fclose($handle);
-                ini_set('auto_detect_line_endings',FALSE);
-                if($csv_data){
-                    $line = 0;
-                    if($csv_data[0][0] == 'digits'){
-                        array_shift($csv_data);
-                        $line++;
-                    }
-                    $new_rate_objs = array();
-                    $error_messages = array();
-                    foreach($csv_data as $data_item){
-                        $line++;
-                        if($data_item !== false){
-                            $tmp_new_obj = $obj->api_create_rate('rate_'.time().'_line_'.$line);
-                            $tmp_new_obj->configure();
-                            $keys = $tmp_new_obj->get_data_keys();
-                            $obj_data = array_combine($keys,$data_item);
-                            $tmp_new_obj->set_data_values($obj_data);
-                            $ouput_msg = array();
-                            if($tmp = $tmp_new_obj->validate($obj_data, $ouput_msg)){
-                                $new_rate_objs[] = $tmp_new_obj;
-                            }else{
-                                $error_messages[]= array(
-                                        'message' => "line [" . $line ."] ",
-                                        'reason' =>  $ouput_msg
-                                );
-                            }
-                            unset($tmp_new_obj);
-                        }
-                    }
-                    if($error_messages){
-                        $output = $error_messages;
-                    }else{
-                        foreach ($old_rate_objects as $obj_item){
-                            $obj_item->dispose();
-                        }
-                        foreach ($new_rate_objs as $new_obj_item){
-                            $new_obj_item->save();
-                        }
-                        $ini_result = true;
-                    }
-                }
-            }
-        }
-        $this->node()->os()->delete_file($file);
-        return $ini_result;
-    }
     public function check_object_usage($src_module_name, $obj_type, $obj_name, $sub_typ=null, $sub_name=null)
     {
         // check usages ?
