@@ -52,9 +52,16 @@ class Fs_sngms_module_class extends Fs_module_class  {
     if($cfg->is_enabled()){
       // force load module sngms
       // force noload for TDM
-      return ($mod_name=="mod_sangoma_media_server.so")?'load':'skip';
+      if ($mod_name=="mod_sangoma_media_server.so"){
+        return 'load';
+      }
+      if ($mod_name=="CORE_PCM_MODULE"){
+        return 'noload';
+      }
+
+      return 'skip';
     }
-    return ($mod_name=="mod_sangoma_media_server.so")?false:'load';
+    return ($mod_name=="mod_sangoma_media_server.so")?'skip':'load';
   }
   /**
    * Returns whether the module is a critical module
