@@ -28,8 +28,8 @@ class Fs_cdr_data extends Sng_data_manager
     {
         parent::__construct();
     }
-    public function index()
+    public function index($module_name, $data_name, $offset = NULL)
     {
-        return $this->manage('cdr','cdr');
+        return $this->manage('cdr','cdr', $offset);
     }
 }
