@@ -118,7 +118,7 @@ class Nsc_rtcpmon extends Safe_CI_Controller
         
         // Set the basic data
         $data['page_title'] = 'RTCP Monitor Reports';
-        $data['page_summary'] = 'This page displays RTCP Monitor Reports.';
+        $data['page_summary'] = 'This page displays RTCP monitor reports.';
         $data['page_large_icon'] = '/images/icons/32x32/icon-network.png';
         $data['page_small_icon'] = '/images/icons/16x16/icon-network.png';
         $data['form_title'] = 'RTCP Monitor Reports';
@@ -181,7 +181,7 @@ class Nsc_rtcpmon extends Safe_CI_Controller
         }
         // Set the basic data
         $data['page_title'] = 'RTCP Monitor Reports';
-        $data['page_summary'] = 'This page displays RTCP Monitor Reports.';
+        $data['page_summary'] = 'This page displays RTCP monitor reports.';
         $data['page_large_icon'] = '/images/icons/32x32/icon-network.png';
         $data['page_small_icon'] = '/images/icons/16x16/icon-network.png';
         $this->load->view("safe_header", $data);
@@ -288,6 +288,7 @@ class Nsc_rtcpmon extends Safe_CI_Controller
         $table = new Safe_crud_table_class();
         $data['table_title'] = $table->set_title('RTCP Monitor Search Results'."({$record_count})");
         // Prepare heading
+        $table->data_formatter = array('none');
         $table->set_headings(array(
                 array(
                         'data' => 'UUID',
@@ -344,8 +345,11 @@ class Nsc_rtcpmon extends Safe_CI_Controller
             if ($row->inflow_rtp_flag == 1) $inflow = 'Inflow';
             else $inflow = 'Outflow';
             // Check if cdr available for this uuid
-            if (TRUE == $cdr_module->data_key_exists('cdr', $row->call_leg_unique_id.'.cdr')) $uuid_col = '<a href="/SAFe/sng_data_manager/view/cdr/cdr/' . $row->call_leg_unique_id . '">' . $row->call_leg_unique_id . '</a>';
-            else $uuid_col = $row->call_leg_unique_id;
+            if (TRUE == $cdr_module->data_key_exists('cdr', $row->call_leg_unique_id.'.cdr')){
+                $uuid_col = '<a style="padding:0px;" href="/SAFe/sng_data_manager/view/cdr/cdr/' . $row->call_leg_unique_id . '">' . $row->call_leg_unique_id . '</a>';
+            }else{
+                $uuid_col = $row->call_leg_unique_id;
+            }
             $table->add_row(array(
                     $uuid_col,
                     //$row->call_leg_unique_id,
