@@ -444,6 +444,8 @@ function safe_confirmation_box(title, content, url_ok, url_cancel, ok_method, ca
 							p_label = defaultvalue(setting['label'], 'Ok');
 							p_url = defaultvalue(setting['url'], '');
 							processing_ui = safe_wait(p_title,'spinning_wheel',p_sec,p_msg,p_label,p_url);
+						}else{
+						    processing_ui = false;
 						}
 						
 						$(this).dialog("close");
