@@ -33,10 +33,10 @@ class Sng_firewall_config_class extends Safe_configurable_object_class
      *           
      * @return
      */
-    public function __construct($node, $parent_name, $name)
+    public function __construct($node, $parent_name)
     {
         // Parent constructor to invoke unserialize if needed
-        parent::__construct($parent_name, $name, $node);
+        parent::__construct($parent_name, "configuration", $node);
     }
     /**
      * @brief Configure the config class object
@@ -71,16 +71,22 @@ class Sng_firewall_service_class extends Safe_service_class
     public function configure()
     {
         // Create the config object
-        $cfg = new Sng_firewall_config_class($this->node(), parent::path(),$this->name());
+        $cfg = new Sng_firewall_config_class($this->node(), $this->path() . '/' . $this->name());
         // Synch with DB
         $cfg->configure();
         $cfg->synch();
         // Attach config to module
         $this->set_config($cfg);
+        // Register the configuration as being pseudo so not exposed to rest
+        $this->register_aggregate_object('configuration', 
+            array(
+                'pseudo' => true
+            )
+        );
 
         return parent::configure();
     }
-    public function can_restore(&$reason)
+    public function can_restore($info, &$reason)
     {
         // Prevent calling parent as service status will be checked
         return true;
@@ -92,8 +98,11 @@ class Sng_firewall_service_class extends Safe_service_class
         if (!isset($stats)) $stats = array();
         $name = strtolower($this->node()->software()->application()->name());
         $stat_file = $this->node()->os()->stat_file('/var/run/' . $name . '.firewall.running');
-        if ($stat_file) $status = Safe_service_class::STATUS_RUNNING;
-        else $status = Safe_service_class::STATUS_STOPPED;
+        if ($stat_file){
+            $status = Safe_service_class::STATUS_RUNNING;
+        }else{
+            $status = Safe_service_class::STATUS_STOPPED;
+        }
         if (isset($stats)) {
             $stats['process'] = 'N/A';
             if (isset($stat_file[9])) {
@@ -105,10 +114,13 @@ class Sng_firewall_service_class extends Safe_service_class
                     $uptime = $uptime - ($days * (24 * 60 * 60));
                 }
                 $uptime = date('H:i:s', $uptime);
-                $stats['cputime'] = $days . $uptime;
-            } else $stats['cputime'] = 'N/A';
-            $stats['%cpu'] = 'N/A';
-            $stats['%mem'] = 'N/A';
+                $stats['cpu']['time'] = $days . $uptime;
+            } else {
+                $stats['cpu']['time'] = 'N/A';
+            }
+            $stats['cpu']['percent'] = 'N/A';
+            $stats['mem']['percent'] = 'N/A';
+            $stats['mem']['kb'] = 'N/A';
         }
         return $status;
     }
