@@ -123,9 +123,7 @@ class Sng_transcoding_config_class extends Safe_configurable_object_class
         }
         $this->add_enum_field('enable_media_interface', 'Enable/Disable Media Interfaces', 'dropdown', 'true', $this->enable_disable_enum());
         $this->set_field_help('enable_media_interface', 'Option to enable/disable media interfaces from being used with the system.');
-        if($internal_adapter){
-            $this->add_field('interfaces', 'interfaces', 'hidden', 'true');
-        }else{
+        if(!$internal_adapter){
             $this->add_multiple_field('interfaces', 'Detect Media Interfaces', 'inline_checkbox', $def_if, $if_name);
             $this->set_field_rules('interfaces', 'required[enable_media_interface]|required[,in,__empty__]');
             
@@ -328,21 +326,11 @@ class Sng_transcoding_config_class extends Safe_configurable_object_class
             }
         }
 
-        $param_data = $this->get_data();
-        if($param_data['enable_media_interface']['type'] == 'hidden'){
+        if($internal_adapter){
             unset($data['interfaces']);
             unset($_POST['interfaces']);
-        }else{
-            if(!isset($data['interfaces']) || $data['enable_media_interface'] == 'false'){
-                //if unchecked all interfaces
-                $data['interfaces'] = '';
-                $_POST['interfaces'] = '';
-            }
-            if($internal_adapter && $data['enable_media_interface'] == 'true'){
-                $data['interfaces'] = implode(',', $internal_adapter_list);
-                $_POST['interfaces'] = $data['interfaces'];
-            }
         }
+
         $validate_result = parent::validate($data, $output);
         $new_data = $this->get_data_values(false);
         $port_begin = intval($new_data['udp_begin']);
